@@ -1,4 +1,4 @@
-#!/usr/bin/env python 
+#!/usr/bin/env python3 
 #
 # Copyright (c) Leipzig, Madrid 1999-2015 Gert Wollny
 #
@@ -73,7 +73,25 @@ def escape_dash(text):
 
 def clean (text):
     text = unescape(text)
-    return escape_dash(text) 
+    return escape_dash(text)
+
+def print_description(text):
+    doi_split = re.split(r'(\[[^\]]*\]\([^)]*\))', text)
+    reg = re.compile(r'\[([^\]]*)\]\(([^)]*)\)')
+    for d in doi_split:
+        if len(d) == 0:
+            continue
+        if d[0] == "[":
+            link = reg.split(d)
+            print("")
+            print(".RS")
+            print(".UR {}".format(link[2]))
+            print(link[1])
+            print(".UE") 
+            print(".RE")
+            print("")
+        else:
+            print(d)
 
 def write_man_file(descr):
     name = escape_dash(descr.name)
@@ -85,7 +103,7 @@ def write_man_file(descr):
     print(".B {}".format (clean(descr.basic_usage)))
     print(".SH DESCRIPTION")
     print(".B {}".format (name))
-    print(descr.description)
+    print_description(descr.description)
     print(".SH OPTIONS")
     for g in descr.option_groups:
         if len(g.name) > 0:
