@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2016 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2017 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,39 +29,11 @@
 
 NS_MIA_BEGIN
 
-template <class T> 
-T2DDatafield<T>::T2DDatafield(const C2DBounds& _Size):
-	m_size(_Size), 
-	m_data(new data_array(m_size.x * m_size.y))
+template <class T>  T2DDatafield<T>::T2DDatafield():
+	m_size(0,0)
 {
 }
 
-template <class T> 
-T2DDatafield<T>::T2DDatafield():
-	m_size(C2DBounds(0,0)), 
-	m_data(new data_array(0))
-{
-}
-
-template <class T> 
-T2DDatafield<T>::T2DDatafield(const C2DBounds& size,const T *_data):
-	m_size(size), 
-	m_data(new data_array(m_size.x * m_size.y))
-{
-	if (_data)
-		::std::copy(_data, _data + m_data->size(), m_data->begin()); 
-	else
-		::std::fill(m_data->begin(), m_data->end(), T()); 
-}
-
-template <class T> 
-T2DDatafield<T>::T2DDatafield(const C2DBounds& size, const std::vector<T>& data):
-	m_size(size),
-	m_data(new data_array(data.begin(), data.end()))
-{
-	assert(m_data->size() == m_size.x * m_size.y); 
-}
-
 template <class T> 
 T2DDatafield<T>::T2DDatafield(const T2DDatafield<T>& org):
 	m_size(org.m_size), 
@@ -69,6 +41,62 @@ T2DDatafield<T>::T2DDatafield(const T2DDatafield<T>& org):
 {
 }
 
+
+template <class T> 
+T2DDatafield<T>& T2DDatafield<T>::operator = (const T2DDatafield<T>& org)
+{
+	if (this != &org) {
+		m_size = org.m_size; 
+		m_data = org.m_data;
+	}
+	return *this; 
+}
+
+
+template <class T> 
+T2DDatafield<T>::T2DDatafield(T2DDatafield<T>&& org):
+	m_size(org.m_size), 
+	m_data(std::move(org.m_data))
+{
+}
+
+template <class T> 
+T2DDatafield<T>& T2DDatafield<T>::operator = (T2DDatafield<T>&& org)
+{
+	if (this != &org) {
+		m_size = org.m_size;
+		m_data = std::move(org.m_data);
+		
+	}
+	return *this; 
+}
+
+template <class T> 
+T2DDatafield<T>::T2DDatafield(const C2DBounds& _Size):
+	m_size(_Size), 
+	m_data(m_size.x * m_size.y)
+{
+}
+
+template <class T> 
+T2DDatafield<T>::T2DDatafield(const C2DBounds& size,const T *_data):
+	m_size(size), 
+	m_data(m_size.x * m_size.y)
+{
+	if (_data)
+		::std::copy(_data, _data + m_data.size(), m_data.begin()); 
+	else
+		::std::fill(m_data.begin(), m_data.end(), T()); 
+}
+
+template <class T> 
+T2DDatafield<T>::T2DDatafield(const C2DBounds& size, const std::vector<T>& data):
+	m_size(size),
+	m_data(data.begin(), data.end())
+{
+	assert(m_data.size() == m_size.x * m_size.y); 
+}
+
 template <class T> 
 T2DDatafield<T>::~T2DDatafield()
 {
@@ -77,32 +105,13 @@ T2DDatafield<T>::~T2DDatafield()
 template <class T> 
 void T2DDatafield<T>::make_single_ref()
 {
-	if (!m_data.unique())
-		m_data = data_pointer(new data_array(*m_data)); 
+ 
 }
 
 template <class T> 
 typename T2DDatafield<T>::size_type T2DDatafield<T>::size() const
 {
-	return m_data->size(); 
-}
-
-template <class T> 
-T T2DDatafield<T>::get_interpol_val_at(const C2DFVector& p) const
-{
-	size_t  x = (size_t )p.x;
-	size_t  y = (size_t )p.y;
-	float  xp = p.x - x; float  xm = 1.0 - xp;
-	float  yp = p.y - y; float  ym = 1.0 - yp;
-	
-	const T& H00 = (*this)(x  ,y  );
-	const T& H01 = (*this)(x  ,y+1);
-	const T& H10 = (*this)(x+1,y  );
-	const T& H11 = (*this)(x+1,y+1);
-	
-	return T(ym * ( xm * H00 + xp * H10) + 
-		 yp * ( xm * H01 + xp * H11));
-
+	return m_data.size(); 
 }
 
 template <class T> 
@@ -114,7 +123,6 @@ const C2DBounds&  T2DDatafield<T>::get_size() const
 template <class T> 
 void T2DDatafield<T>::clear()
 {
-	make_single_ref();
 	std::fill(begin(), end(),T()); 
 }
 	
@@ -123,7 +131,7 @@ typename T2DDatafield<T>::reference
 T2DDatafield<T>::operator()(size_t  x, size_t  y)
 {
 	if (x < m_size.x && y < m_size.y){	
-		return (*m_data)[x + m_size.x * y ];
+		return m_data[x + m_size.x * y ];
 	}else{
 		//FORCECOREDUMP;
 		throw std::invalid_argument("T2DDatafield<T>::operator(x,y,z):Index out of bounds");
@@ -135,10 +143,8 @@ template <class T>
 typename T2DDatafield<T>::const_reference
 T2DDatafield<T>::operator()(size_t  x, size_t  y)const
 {
-	const data_array& cData = *m_data; 
-	
 	if ( x < m_size.x && y < m_size.y ){
-		return cData[ x + m_size.x * y ];
+		return m_data[ x + m_size.x * y ];
 	}else{
 		return Zero;
 	}
@@ -147,10 +153,8 @@ template <class T>
 typename T2DDatafield<T>::const_reference
 T2DDatafield<T>::operator()(const C2DBounds& l)const
 {
-	const data_array& cData = *m_data; 
-	
 	if ( l.x < m_size.x && l.y < m_size.y ){
-		return cData[ l.x + m_size.x * l.y ];
+		return m_data[ l.x + m_size.x * l.y ];
 	}else{
 		return Zero;
 	}
@@ -168,9 +172,8 @@ void T2DDatafield<T>::get_data_line_x(size_t y, std::vector<T>& buffer)const
 {
 	assert(y < m_size.y); 
 	buffer.resize(m_size.x); 
-
-	const data_array& d = *m_data; 
-	const_iterator b = d.begin(); 
+ 
+	const_iterator b = m_data.begin(); 
 	advance(b, y * m_size.x); 
 
 	std::copy(b, b + m_size.x, buffer.begin()); 
@@ -181,9 +184,8 @@ void T2DDatafield<T>::get_data_line_y(size_t x, std::vector<T>& buffer)const
 {
 	assert(x < m_size.x); 
 	buffer.resize(m_size.y); 
-
-	const data_array& d = *m_data; 
-	const_iterator src = d.begin(); 
+ 
+	const_iterator src = m_data.begin(); 
 	advance(src,x);
 	typename std::vector<T>::iterator dest_i = buffer.begin(); 
 	typename std::vector<T>::iterator dest_e = buffer.end(); 
@@ -201,9 +203,8 @@ void T2DDatafield<T>::put_data_line_x(size_t y,  const std::vector<T>& buffer)
 {
 	assert(y < m_size.y); 
 	assert(buffer.size() == m_size.x); 
-	make_single_ref();
 
-	std::copy(buffer.begin(), buffer.end(), m_data->begin() + m_size.x * y ); 
+	std::copy(buffer.begin(), buffer.end(), m_data.begin() + m_size.x * y ); 
 }
      
 template <class T> 
@@ -212,9 +213,8 @@ void T2DDatafield<T>::put_data_line_y(size_t x, const std::vector<T>& buffer)
 	assert(x < m_size.x); 
 	assert(buffer.size() == m_size.y); 
 	
-	make_single_ref();
-	typename std::vector<T>::const_iterator src_i = buffer.begin();
-	typename std::vector<T>::const_iterator src_e = buffer.end();
+	auto src_i = buffer.begin();
+	auto src_e = buffer.end();
 	
 	iterator dest = begin(); 
 	advance(dest, x); 
@@ -227,19 +227,21 @@ void T2DDatafield<T>::put_data_line_y(size_t x, const std::vector<T>& buffer)
 	}
 }
 
-template <class T> 
-T2DDatafield<T>& T2DDatafield<T>::operator = (const T2DDatafield<T>& org)
-	
+template <typename T>
+typename T2DDatafield<T>::Range
+T2DDatafield<T>::get_range(const C2DBounds& start, const C2DBounds& end)
 {
-	if (&org == this){
-		return *this;
-	}
-	
-	m_size = org.m_size;
-	m_data = org.m_data;
-	return *this; 
+	return Range(start, end, *this); 
 }
 
+template <typename T>
+typename T2DDatafield<T>::ConstRange
+T2DDatafield<T>::get_range(const C2DBounds& start, const C2DBounds& end) const
+{
+	return ConstRange(start, end, *this); 
+}
+
+
 template <typename T>
 typename T2DDatafield<T>::range_iterator 
 T2DDatafield<T>::begin_range(const C2DBounds& begin, const C2DBounds& end)
@@ -272,6 +274,50 @@ T2DDatafield<T>::end_range(const C2DBounds& begin, const C2DBounds& end)const
 				    begin_at(end.x, end.y)); 
 }
 
+template <typename T>
+typename T2DDatafield<T>::Range::iterator T2DDatafield<T>::Range::begin()
+{
+	return m_begin; 
+}
+
+template <typename T>
+typename T2DDatafield<T>::Range::iterator T2DDatafield<T>::Range::end()
+{
+	return m_end; 
+}
+
+template <typename T>
+T2DDatafield<T>::Range::Range(const C2DBounds& start, const C2DBounds& end, T2DDatafield<T>& field):
+	m_begin(field.begin_range(start, end)), m_end(field.end_range(start, end))
+{
+}
+					    
+
+template <typename T>
+typename T2DDatafield<T>::ConstRange::iterator T2DDatafield<T>::ConstRange::begin() const 
+{
+	return m_begin; 
+}
+
+template <typename T>
+typename T2DDatafield<T>::ConstRange::iterator T2DDatafield<T>::ConstRange::end() const 
+{
+	return m_end; 
+}
+
+
+template <typename T>
+T2DDatafield<T>::ConstRange::ConstRange(const C2DBounds& start, const C2DBounds& end, const T2DDatafield<T>& field):
+	m_begin(field.begin_range(start, end)), m_end(field.end_range(start, end))
+{
+}
+
+template <typename T>
+T2DDatafield<T>::ConstRange::ConstRange(const Range& range):
+	m_begin(range.m_begin), m_end(range.m_end)
+{
+}
+
 
 template <class T> 
 const typename  T2DDatafield<T>::value_type T2DDatafield<T>::Zero = T();
