@@ -1,6 +1,6 @@
 /* -*- mia-c++  -*-
  *
- * This file is part of MIA - a toolbox for medical image analysis 
+ * This file is part of MIA - a toolbox for medical image analysis
  * Copyright (c) Leipzig, Madrid 1999-2017 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
@@ -31,34 +31,34 @@
 
 NS_MIA_USE
 using namespace std;
-namespace bmpl=boost::mpl;
+namespace bmpl = boost::mpl;
 
 struct FTestFilter : public TFilter<bool> {
-	template <typename T>
-	bool operator () (const T2DImage<T>& image) const {
-		return image.size() != 0; 
-	}
-	
-}; 
+       template <typename T>
+       bool operator () (const T2DImage<T>& image) const
+       {
+              return image.size() != 0;
+       }
+
+};
 
 typedef bmpl::vector<bool,
-		     int8_t,
-		     uint8_t,
-		     int16_t,
-		     uint16_t,
-		     int32_t,
-		     uint32_t,
-		     int64_t,
-		     uint64_t,
-		     float,
-		     double
-		     > test_types;
+        int8_t,
+        uint8_t,
+        int16_t,
+        uint16_t,
+        int32_t,
+        uint32_t,
+        int64_t,
+        uint64_t,
+        float,
+        double
+        > test_types;
 
 BOOST_AUTO_TEST_CASE_TEMPLATE( test_test_type, T, test_types )
-{	
-	T2DImage<T> timage(C2DBounds(1,1)); 
-	const C2DImage& image = timage; 
-	FTestFilter filter; 
-	
-	BOOST_CHECK(mia::filter(filter, image)); 
+{
+       T2DImage<T> timage(C2DBounds(1, 1));
+       const C2DImage& image = timage;
+       FTestFilter filter;
+       BOOST_CHECK(mia::filter(filter, image));
 }
