@@ -1,6 +1,6 @@
 /* -*- mia-c++  -*-
  *
- * This file is part of MIA - a toolbox for medical image analysis 
+ * This file is part of MIA - a toolbox for medical image analysis
  * Copyright (c) Leipzig, Madrid 1999-2017 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
@@ -37,29 +37,30 @@ using namespace mia;
 
 
 const SProgramDescription g_description = {
-	{pdi_group, "Miscellaneous programs"}, 
-	{pdi_short, "File name number pattern analysis"}, 
-	{pdi_description, "This program is used to extract a extract the number pattern for "
-	 "file012312.ext type file names."}
-}; 
+       {pdi_group, "Miscellaneous programs"},
+       {pdi_short, "File name number pattern analysis"},
+       {
+              pdi_description, "This program is used to extract a extract the number pattern for "
+              "file012312.ext type file names."
+       }
+};
 
 int do_main( int argc, char *argv[] )
 {
-	string in_filename;
-	CCmdOptionList options(g_description);
-	options.add(make_opt( in_filename, "in-file", 'i', "input image example name", 
-			      CCmdOptionFlags::required_input));
-	options.set_stdout_is_result(); 
+       string in_filename;
+       CCmdOptionList options(g_description);
+       options.add(make_opt( in_filename, "in-file", 'i', "input image example name",
+                             CCmdOptionFlags::required_input));
+       options.set_stdout_is_result();
 
-	if (options.parse(argc, argv) != CCmdOptionList::hr_no)
-		return EXIT_SUCCESS; 
+       if (options.parse(argc, argv) != CCmdOptionList::hr_no)
+              return EXIT_SUCCESS;
 
-	size_t format_width = get_filename_number_pattern_width(in_filename);
-	cout << setw(format_width) << setfill('0') << 0;
-
-	// end of program, so it's not important to restore the stream state
-	// coverity[stream_format_state] 
-	return 0;
+       size_t format_width = get_filename_number_pattern_width(in_filename);
+       cout << setw(format_width) << setfill('0') << 0;
+       // end of program, so it's not important to restore the stream state
+       // coverity[stream_format_state]
+       return 0;
 }
 
-MIA_MAIN(do_main); 
+MIA_MAIN(do_main);
